using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace QueryExpressions
{
    class Program
    {
        static void Main(string[] args)
        {
            Examples1_7.LinqQueryExpression();
            Examples1_7.WithoutLinq();
            Examples1_7.ExtractOneProperty();
            Examples1_7.ExpandedQuery();
            Examples1_7.ExpandTrivialSelect();
            Examples1_7.LetClause();
            Examples1_7.ExpandedLet();
            Examples8_10.QuerySillyProvider();
            Examples8_10.ExpandedSillyQuery();
        }
    }
}
